CreateFrame("Frame", "Clock", Clockbar)
ClockButtonFrame:SetScale(2)
ClockButtonFrame:SetParent(Clock)
local menuButtons
do
	local loadButtons = function(...)
		menuButtons = {}
		
		for i = 1, select('#', ...) do
			local b = select(i, ...)
			local name = b:GetName()
			table.insert(menuButtons, b)
		end
	end
	loadButtons(_G['Clock']:GetChildren())
end

--[[ Minimap ]]--
local DMAP = Dominos:NewModule('Clock')
local MAP

function DMAP:Load()
	self.frame = MAP:New()
	self.frame:SetFrameStrata('LOW')

end
function DMAP:Unload()
	self.frame:Free()
end

MAP = Dominos:CreateClass('Frame', Dominos.Frame)

function MAP:New()
	local f = self.super.New(self, 'Clock')
	if not f.value then
		f:SetFrameStrata('BACKGROUND')
		f:LoadButtons()
	end

	f:Layout()


	return f
end

function MAP:GetDefaults()
	return {
		scale = 1,
		point = 'CENTER',
		y = 0,
		x = 0,
	}
end
function MAP:NumButtons()
	return #menuButtons
end

function MAP:AddButton(i)
	local b = menuButtons[i]
	if b then
		b:SetParent(self.header)
		b:Show()

		self.buttons[i] = b
	end
end

function MAP:RemoveButton(i)
	local b = self.buttons[i]
	if b then
		b:SetParent(nil)
		b:Hide()

		self.buttons[i] = nil
	end
end
local WIDTH_OFFSET = -(ClockButtonFrame:GetWidth())
local HEIGHT_OFFSET = -(ClockButtonFrame:GetHeight())

function MAP:Layout()
	if #self.buttons > 0 then
		local cols = min(self:NumColumns(), #self.buttons)
		local rows = ceil(#self.buttons / cols)
		local pW, pH = self:GetPadding()
		local spacing = self:GetSpacing()

		local b = self.buttons[1]
		local w = b:GetWidth() + spacing - WIDTH_OFFSET
		local h = b:GetHeight() + spacing - HEIGHT_OFFSET

		for i,b in pairs(self.buttons) do
			local col = (i-1) % cols
			local row = ceil(i / cols) - 1
			b:ClearAllPoints()
			b:SetPoint('CENTER', 0, 0)
		end

		self:SetWidth(max(w*ceil(#self.buttons/cols) - spacing + pW*2, 8))
		self:SetHeight(max(h*ceil(#self.buttons/cols) - spacing + pH*2, 8))
	else
		self:SetWidth(30); self:SetHeight(30)
	end
end
--[[ Menu Code ]]--
local function AddLayoutPanel(menu)
	local p = menu:NewPanel(LibStub('AceLocale-3.0'):GetLocale('Dominos-Config').Layout)
	p:NewPaddingSlider()
	p:NewOpacitySlider()
	p:NewFadeSlider()
	p:NewScaleSlider()
end


function MAP:CreateMenu()
	local menu = Dominos:NewMenu(self.id)
	AddLayoutPanel(menu)
	self.menu = menu
end